@@ -5,32 +5,24 @@
 
     Test setup_command for distutils.
 
-    :copyright: Copyright 2007-2016 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2018 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
 import os
-import sys
 import subprocess
+import sys
 from collections import namedtuple
-import sphinx
+from textwrap import dedent
 
 import pytest
 
+import sphinx
 from sphinx.util.osutil import cd
-from util import rootdir, tempdir
-from textwrap import dedent
-
-root = tempdir / 'test-setup'
-
-
-def setup_module():
-    if not root.exists():
-        (rootdir / 'roots' / 'test-setup').copytree(root)
 
 
 @pytest.fixture
-def setup_command(request, tempdir):
+def setup_command(request, tempdir, rootdir):
     """
     Run `setup.py build_sphinx` with args and kwargs,
     pass it to the test and clean up properly.
@@ -38,8 +30,8 @@ def setup_command(request, tempdir):
     marker = request.node.get_marker('setup_command')
     args = marker.args if marker else []
 
-    pkgrootdir = tempdir / 'root'
-    root.copytree(pkgrootdir)
+    pkgrootdir = tempdir / 'test-setup'
+    (rootdir / 'test-setup').copytree(pkgrootdir)
 
     with cd(pkgrootdir):
         pythonpath = os.path.dirname(os.path.dirname(sphinx.__file__))
@@ -64,6 +56,24 @@ def test_build_sphinx(setup_command):
     assert proc.returncode == 0
 
 
+@pytest.mark.setup_command('-b', 'html,man')
+def test_build_sphinx_multiple_builders(setup_command):
+    proc = setup_command.proc
+    out, err = proc.communicate()
+    print(out)
+    print(err)
+    assert proc.returncode == 0
+
+
+@pytest.mark.setup_command('-b', 'html,bar')
+def test_build_sphinx_multiple_invalid_builders(setup_command):
+    proc = setup_command.proc
+    out, err = proc.communicate()
+    print(out)
+    print(err)
+    assert proc.returncode == 1
+
+
 @pytest.fixture
 def nonascii_srcdir(request, setup_command):
     mb_name = u'\u65e5\u672c\u8a9e'
@@ -71,7 +81,7 @@ def nonascii_srcdir(request, setup_command):
     try:
         (srcdir / mb_name).makedirs()
     except UnicodeEncodeError:
-        from path import FILESYSTEMENCODING
+        from sphinx.testing.path import FILESYSTEMENCODING
         pytest.skip(
             'non-ASCII filename not supported on this filesystem encoding: '
             '%s' % FILESYSTEMENCODING)
@@ -83,11 +93,10 @@ def nonascii_srcdir(request, setup_command):
 
     master_doc = srcdir / 'contents.txt'
     master_doc.write_bytes((master_doc.text() + dedent("""
-            .. toctree::
+                            .. toctree::
 
-               %(mb_name)s/%(mb_name)s
-            """ % locals())
-                            ).encode('utf-8'))
+                               %(mb_name)s/%(mb_name)s
+                            """ % locals())).encode('utf-8'))
 
 
 @pytest.mark.usefixtures('nonascii_srcdir')
